==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/CHANGELOG.md <==
# Changelog

## 4.2.1 - 2024-02-08

### Fixed

- #4913 Bien prendre en compte les éventuelles largeur & hauteur passées au modèle lors de l'insertion d'une image SVG
- #4933 Passer l'édition du logo du site dans une modale
- #4984 Utiliser le filtre `icone_verticale` et non `icone` qui est déprécié
- #4981 Dans le formulaire d'édition de document, utiliser `descriptif` et pas `description`

## 4.2.0 - 2024-01-11

### Added

- #4914 Option `masquer` pour masquer en tout ou partie la légende. Valeurs possibles (séparées par une virgule) : `legende`, `titre`, `descriptif`, `credits`
- #4293 Ajout d'un génie pour supprimer les fichiers trop vieux du répertoire `tmp/upload`
- #4892 Petit ajout afin d'activer un diaporama sur la modale des images dans la médiathèque

## 4.1.5 - 2024-01-11

### Fixed

- #4978 Réparer la fonction Joindre un fichier Zip depuis /tmp/upload
- #4970 Rétablir la suppression du numéro sur le titre dans la légende des documents
- #4913 Bien prendre en compte les éventuelles largeur & hauteur passées au modèle lors de l'insertion d'une image SVG

## 4.1.4 - 2023-12-18

### Fixed

- #4968 Accolade manquante dans modeles/file.html
- #4959 Prise en compte du nombre de pagination choisie dans la popin de médiathèque.
- #4957 Accessibilité et UX des boutons de gestion des documents
- #4952 HTML mal formé sur modeles/document_desc.html

## 4.1.3 - 2023-10-05

### Fixed

- #4962 Corriger le choix de la méthode d'upload par défaut
- #4931 Normaliser `autoriser_document_voir()` pour retourner toujours un booleen
- #4941 Compléter le jeu d’icones pour certains types de documents
- #4946 Affichage des puces statut des documents dans la médiathèque
- #4944 Ne pas appliquer 2 fois les traitements typo sur les titres, descriptifs et crédits de document

## 4.1.2 - 2023-09-01

### Fixed

- #4937 Éviter une fatale sur media_determine_autolien avec des tailles nulles
- Exclure les tests et fichiers de développement des livrables
- spip/spip#3637 Lever l'ambiguité sur les balises simples des `url()`

## 4.1.1 - 2023-06-07

### Security

- spip-team/securite#4841 Limiter l’usage de `#ENV**` dans les formulaires.

### Changed

- Utiliser `spip_livrer_fichier()` pour envoyer les fichiers (refactor)


## 4.1.0 - 2023-01-27

### Added

- spip/spip#3719 Permettre d’éditer un logo
- Fichier `README.md`

### Changed

- Compatible SPIP 4.2.0-dev

### Removed

- spip/safehtml#4786 Suppression du Sanitizer SVG qui est maintenant dans le plugin SafeHtml
- Suppression du formulaire `FORMULAIRE_CHANGER_FICHIER_DOCUMENT` qui n'est plus utilisé par SPIP (la fonctionnalité se trouve directement dans `FORMULAIRE_EDITER_DOCUMENT`)

### Fixed

- #4919 Correction d'une inversion entre taille des images et des logos dans le test des tailles acceptables
- spip/spip#5274 Homogénéiser les labels des listes
- #4902 Suppression des boutons excédentaires de sens de tri sur certaines listes de documents

==> spip_4.2.11+dfsg.orig.tar.xz: plugins-dist/medias/CHANGELOG.md <==
# Changelog

## 4.2.3 - 2024-04-05

### Fixed

- spip/spip#5894 La liste des documents doit lister aussi les documents orphelins

## 4.2.2 - 2024-03-08

### Fixed

- #4990 Réparer l'affichage du premier documents joints uploadé depuis `exec=article_edit`

## 4.2.1 - 2024-02-08

### Fixed

- #4913 Bien prendre en compte les éventuelles largeur & hauteur passées au modèle lors de l'insertion d'une image SVG
- #4933 Passer l'édition du logo du site dans une modale
- #4984 Utiliser le filtre `icone_verticale` et non `icone` qui est déprécié
- #4981 Dans le formulaire d'édition de document, utiliser `descriptif` et pas `description`

## 4.2.0 - 2024-01-11

### Added

- #4914 Option `masquer` pour masquer en tout ou partie la légende. Valeurs possibles (séparées par une virgule) : `legende`, `titre`, `descriptif`, `credits`
- #4293 Ajout d'un génie pour supprimer les fichiers trop vieux du répertoire `tmp/upload`
- #4892 Petit ajout afin d'activer un diaporama sur la modale des images dans la médiathèque

## 4.1.5 - 2024-01-11

### Fixed

- #4978 Réparer la fonction Joindre un fichier Zip depuis /tmp/upload
- #4970 Rétablir la suppression du numéro sur le titre dans la légende des documents
- #4913 Bien prendre en compte les éventuelles largeur & hauteur passées au modèle lors de l'insertion d'une image SVG

## 4.1.4 - 2023-12-18

### Fixed

- #4968 Accolade manquante dans modeles/file.html
- #4959 Prise en compte du nombre de pagination choisie dans la popin de médiathèque.
- #4957 Accessibilité et UX des boutons de gestion des documents
- #4952 HTML mal formé sur modeles/document_desc.html

## 4.1.3 - 2023-10-05

### Fixed

- #4962 Corriger le choix de la méthode d'upload par défaut
- #4931 Normaliser `autoriser_document_voir()` pour retourner toujours un booleen
- #4941 Compléter le jeu d’icones pour certains types de documents
- #4946 Affichage des puces statut des documents dans la médiathèque
- #4944 Ne pas appliquer 2 fois les traitements typo sur les titres, descriptifs et crédits de document

## 4.1.2 - 2023-09-01

### Fixed

- #4937 Éviter une fatale sur media_determine_autolien avec des tailles nulles
- Exclure les tests et fichiers de développement des livrables
- spip/spip#3637 Lever l'ambiguité sur les balises simples des `url()`

## 4.1.1 - 2023-06-07

### Security

- spip-team/securite#4841 Limiter l’usage de `#ENV**` dans les formulaires.

### Changed

- Utiliser `spip_livrer_fichier()` pour envoyer les fichiers (refactor)


## 4.1.0 - 2023-01-27

### Added

- spip/spip#3719 Permettre d’éditer un logo
- Fichier `README.md`

### Changed

- Compatible SPIP 4.2.0-dev

### Removed

- spip/safehtml#4786 Suppression du Sanitizer SVG qui est maintenant dans le plugin SafeHtml
- Suppression du formulaire `FORMULAIRE_CHANGER_FICHIER_DOCUMENT` qui n'est plus utilisé par SPIP (la fonctionnalité se trouve directement dans `FORMULAIRE_EDITER_DOCUMENT`)

### Fixed

- #4919 Correction d'une inversion entre taille des images et des logos dans le test des tailles acceptables
- spip/spip#5274 Homogénéiser les labels des listes
- #4902 Suppression des boutons excédentaires de sens de tri sur certaines listes de documents
